scanBarcodesWithConfiguration static method

Future<Map> scanBarcodesWithConfiguration(
  1. Map configuration
)

Starts a barcode scanning flow

It takes a configuration parameter which can take the following options:

  • isBatchModeEnabled: boolean (defaults to false). If true, multiple codes can be scanned in a single session.
  • supportedCodeTypes: an array of the barcode types to scan, e.g. ['qr', 'code39']. Possible values are aztec, code39, code93, code128, dataMatrix, ean8, ean13, itf, pdf417, qr, upca (Android only), upce, codabar (iOS 15+ only), gs1DataBar (iOS 15+ only), microPDF417 (iOS 15+ only), microQR (iOS 15+ only), msiPlessey (iOS 17+ only). Defaults to all supported types.

It returns a Future<Map> containing:

  • barcodes: an array of barcodes. Each barcode has:
    • value: The decoded string value of the code
    • type: The type of code (e.g., "qr", "code128", etc.)

Implementation

static Future<Map> scanBarcodesWithConfiguration(Map configuration) async {
  return await _channel.invokeMethod('scanBarcodesWithConfiguration', configuration);
}